@@ -215,6 +215,8 @@ class Testutil(unittest.TestCase):
         w = util.WSP2W(wsp)
         self.assertEqual(w.n, 10)
         self.assertEqual(w[0], {1: 1, 5: 1})
+        for weights in w.weights.values():
+            assert isinstance(weights, list)
         w = psopen(examples.get_path("sids2.gal"), "r").read()
         wsp = WSP(w.sparse, w.id_order)
         w = util.WSP2W(wsp)
