@@ -24,6 +24,7 @@ except ImportError:
 
 try:
     from shapely.geometry.base import BaseGeometry
+
     HAS_SHAPELY = True
 except ImportError:
     HAS_SHAPELY = False
@@ -534,17 +535,17 @@ def higher_order_sp(
         )
 
     if lower_order:
-        wk = sum(map(lambda x: w ** x, range(2, k + 1)))
+        wk = sum(map(lambda x: w**x, range(2, k + 1)))
         shortest_path = False
     else:
-        wk = w ** k
+        wk = w**k
 
     rk, ck = wk.nonzero()
     sk = set(zip(rk, ck))
 
     if shortest_path:
         for j in range(1, k):
-            wj = w ** j
+            wj = w**j
             rj, cj = wj.nonzero()
             sj = set(zip(rj, cj))
             sk.difference_update(sj)
@@ -786,7 +787,6 @@ def full2W(m, ids=None, **kwargs):
 
 
 def WSP2W(wsp, **kwargs):
-
     """
     Convert a pysal WSP object (thin weights matrix) to a pysal W object.
 
@@ -826,14 +826,12 @@ def WSP2W(wsp, **kwargs):
 
 
     """
-    wsp.sparse
-    indices = wsp.sparse.indices
     data = wsp.sparse.data
     indptr = wsp.sparse.indptr
     id_order = wsp.id_order
     if id_order:
         # replace indices with user IDs
-        indices = [id_order[i] for i in indices]
+        indices = [id_order[i] for i in wsp.sparse.indices]
     else:
         id_order = list(range(wsp.n))
     neighbors, weights = {}, {}
@@ -842,7 +840,7 @@ def WSP2W(wsp, **kwargs):
         oid = id_order[i]
         end = indptr[i + 1]
         neighbors[oid] = indices[start:end]
-        weights[oid] = data[start:end]
+        weights[oid] = data[start:end].tolist()
         start = end
     ids = copy.copy(wsp.id_order)
     w = W(neighbors, weights, ids, **kwargs)
@@ -1086,12 +1084,7 @@ def get_points_array(iterable):
                 ]
             )
         else:
-            data = np.vstack(
-                [
-                    np.array(shape.centroid)
-                    for shape in first_choice
-                ]
-            )
+            data = np.vstack([np.array(shape.centroid) for shape in first_choice])
     except AttributeError:
         data = np.vstack([shape for shape in backup])
     return data
@@ -1692,7 +1685,6 @@ def fuzzy_contiguity(
 
 
 if __name__ == "__main__":
-
     from libpysal.weights import lat2W
 
     assert (lat2W(5, 5).sparse.todense() == lat2SW(5, 5).todense()).all()
